@@ -13,7 +13,7 @@ API_HEADERS = {}
 
 class WinkApiInterface(object):
 
-    BASE_URL = "https://winkapi.quirky.com"
+    BASE_URL = "https://api.wink.com"
 
     def set_device_state(self, device, state, id_override=None):
         """
@@ -106,6 +106,10 @@ def get_sirens():
     return get_devices(device_types.SIREN)
 
 
+def get_keys():
+    return get_devices(device_types.KEY)
+
+
 def get_subscription_key():
     response_dict = wink_api_fetch()
     first_device = response_dict.get('data')[0]
