@@ -7,6 +7,7 @@ GARAGE_DOOR = 'garage_door'
 POWER_STRIP = 'powerstrip'
 SHADE = 'shades'
 SIREN = 'siren'
+KEY = 'key'
 
 DEVICE_ID_KEYS = {
     BINARY_SWITCH: 'binary_switch_id',
@@ -17,5 +18,6 @@ DEVICE_ID_KEYS = {
     POWER_STRIP: 'powerstrip_id',
     SENSOR_POD: 'sensor_pod_id',
     SHADE: 'shade_id',
-    SIREN: 'siren_id'
+    SIREN: 'siren_id',
+    KEY: 'key_id'
 }
